==> ssp-center-api-0.9.73-yqf-20210824.111316-2-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteSlotStableChargeBackendService.java <==
package cn.com.duiba.tuia.ssp.center.api.remote;


import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.ssp.center.api.dto.SlotStableChargeDto;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.List;

/**
 * 长期计费服务接口
 */
@AdvancedFeignClient
public interface RemoteSlotStableChargeBackendService {
    /**
     * 根据appId查询所有广告位的分成比例配置信息
     * @param appId
     * @return
     */
    DubboResult<List<SlotStableChargeDto>> selectByAppId(Long appId);

    /**
     * 根据slotId更新配置信息
     * @param slotStableChargeDto
     * @return
     */
    DubboResult<Boolean> update(SlotStableChargeDto slotStableChargeDto);

    /**
     * @Description  更新托管状态
     * @Date 20:59 2020-10-14
     * @Param [slotStableChargeDto]
     * @return java.lang.Boolean
     **/
    Boolean updateHosting(SlotStableChargeDto slotStableChargeDto);

    /**
     * 插入一条配置信息
     * @param slotStableChargeDto
     * @return
     */
    DubboResult<Boolean> insert(SlotStableChargeDto slotStableChargeDto);

    /**
     * 批量更新分成浮动值
     * @param slotStableChargeDtos
     * @return
     */
    DubboResult<Boolean> batchUpdate(List<SlotStableChargeDto> slotStableChargeDtos);

    SlotStableChargeDto getStableChargeBySlotIdAndChargeType(Long slotId,Integer chargeType);

    /**
     * @Author zhangliwei
     * @Description  根据广告位ID集合查询长期计费集合
     * @Date 22:43 2020-03-11
     * @Param [appId]
     * @return cn.com.duiba.wolf.dubbo.DubboResult<java.util.List<cn.com.duiba.tuia.ssp.center.api.dto.SlotStableChargeDto>>
     **/
    List<SlotStableChargeDto> selectBySlotIds(List<Long> slotIds);
}

==> ssp-center-api-1.2.90-yqf-20251118.063257-2-sources.jar: cn/com/duiba/tuia/ssp/center/api/remote/RemoteSlotStableChargeBackendService.java <==
package cn.com.duiba.tuia.ssp.center.api.remote;


import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.tuia.activity.center.api.common.Pageable;
import cn.com.duiba.tuia.ssp.center.api.dto.SlotStableChargeDto;
import cn.com.duiba.tuia.ssp.center.api.query.SlotStableChargeQuery;
import cn.com.duiba.wolf.dubbo.DubboResult;

import java.util.List;

/**
 * 长期计费服务接口
 */
@AdvancedFeignClient
public interface RemoteSlotStableChargeBackendService {
    /**
     * 根据appId查询所有广告位的分成比例配置信息
     * @param appId
     * @return
     */
    DubboResult<List<SlotStableChargeDto>> selectByAppId(Long appId);

    /**
     * 根据slotId更新配置信息
     * @param slotStableChargeDto
     * @return
     */
    DubboResult<Boolean> update(SlotStableChargeDto slotStableChargeDto);

    /**
     * @Description  更新托管状态
     * @Date 20:59 2020-10-14
     * @Param [slotStableChargeDto]
     * @return java.lang.Boolean
     **/
    DubboResult<Boolean> updateHosting(SlotStableChargeDto slotStableChargeDto);

    /**
     * 插入一条配置信息
     * @param slotStableChargeDto
     * @return
     */
    DubboResult<Boolean> insert(SlotStableChargeDto slotStableChargeDto);

    /**
     * 批量更新分成浮动值
     * @param slotStableChargeDtos
     * @return
     */
    DubboResult<Boolean> batchUpdate(List<SlotStableChargeDto> slotStableChargeDtos);

    SlotStableChargeDto getStableChargeBySlotIdAndChargeType(Long slotId,Integer chargeType);

    /**
     * @Author zhangliwei
     * @Description  根据广告位ID集合查询长期计费集合
     * @Date 22:43 2020-03-11
     * @Param [appId]
     * @return cn.com.duiba.wolf.dubbo.DubboResult<java.util.List<cn.com.duiba.tuia.ssp.center.api.dto.SlotStableChargeDto>>
     **/
    List<SlotStableChargeDto> selectBySlotIds(List<Long> slotIds);

    List<SlotStableChargeDto> findList(SlotStableChargeQuery queryParam, Pageable pageable);

}
